# frozen_string_literal: true

module Ai
  module DuoWorkflows
    class Event < ::ApplicationRecord
      UUID_REGEXP = /\A[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\z/i

      self.table_name = :duo_workflows_events

      belongs_to :workflow, class_name: 'Ai::DuoWorkflows::Workflow'
      belongs_to :project

      validates :event_type, presence: true
      validates :event_status, presence: true
      validates :correlation_id_value, uniqueness: true, allow_nil: true,
        format: { with: UUID_REGEXP, message: 'must be a valid UUID', if: :correlation_id_value? }

      alias_attribute :correlation_id, :correlation_id_value

      enum event_type: { pause: 0, resume: 1, stop: 2, message: 3, response: 4, require_input: 5 }
      enum event_status: { queued: 0, delivered: 1 }

      scope :queued, -> { where(event_status: event_statuses[:queued]) }
      scope :delivered, -> { where(event_status: event_statuses[:delivered]) }
      scope :with_correlation_id, ->(correlation_id) { where(correlation_id_value: correlation_id) }
    end
  end
end
