# frozen_string_literal: true

module EE
  module Banzai
    module Filter
      module References
        # HTML filter that replaces epic references with links. References to
        # epics that do not exist are ignored.
        #
        # This filter supports cross-project/group references.
        module EpicReferenceFilter
          extend ActiveSupport::Concern

          def references_in(text, pattern = object_class.reference_pattern)
            ::Gitlab::Utils::Gsub
              .gsub_with_limit(text, pattern, limit: ::Banzai::Filter::FILTER_ITEM_LIMIT) do |match_data|
              symbol = match_data[object_sym]
              if object_class.reference_valid?(symbol)
                yield match_data[0], symbol.to_i, nil, match_data[:group], match_data
              else
                match_data[0]
              end
            end
          end

          def url_for_object(epic, group)
            urls = ::Gitlab::Routing.url_helpers
            urls.group_epic_url(group, epic, only_path: context[:only_path])
          end

          def reference_class(object_sym, tooltip: false)
            super
          end

          def data_attributes_for(text, group, object, link_content: false, link_reference: false)
            {
              original: escape_html_entities(text),
              link: link_content,
              link_reference: link_reference,
              group: group.id,
              group_path: group.full_path,
              iid: object.iid,
              object_sym => object.id
            }
          end

          # rubocop: disable CodeReuse/ActiveRecord
          def parent_records(parent, ids)
            return ::Epic.none unless parent.is_a?(Group)

            parent.epics.where(iid: ids.to_a)
          end
          # rubocop: enable CodeReuse/ActiveRecord

          def parent_type
            :group
          end
        end
      end
    end
  end
end
