# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Groups::AutocompleteSourcesController, feature_category: :team_planning do
  let_it_be(:user) { create(:user) }
  let_it_be(:group) { create(:group) }
  let_it_be(:project) { create(:project, :public, group: group) }
  let_it_be(:group_issue) { create(:work_item, :group_level, namespace: group) }
  let_it_be(:project_issue) { create(:work_item, project: project) }
  let_it_be(:work_item_epic) { create(:work_item, :epic, :group_level, namespace: group) }

  before do
    sign_in(user)
  end

  describe '#issues', feature_category: :portfolio_management do
    it 'returns response with group level work items', :aggregate_failures do
      issues_json_response = [
        {
          'iid' => work_item_epic.iid,
          'title' => work_item_epic.title,
          'reference' => work_item_epic.to_reference,
          'icon_name' => 'issue-type-epic'
        },
        {
          'iid' => project_issue.iid,
          'title' => project_issue.title,
          'reference' => project_issue.to_reference(group),
          'icon_name' => 'issue-type-issue'
        },
        {
          'iid' => group_issue.iid,
          'title' => group_issue.title,
          'reference' => group_issue.to_reference,
          'icon_name' => 'issue-type-issue'
        }
      ]

      get :issues, params: { group_id: group }

      expect(response).to have_gitlab_http_status(:ok)
      expect(json_response).to be_an(Array)
      expect(json_response.count).to eq(3)
      expect(json_response).to match_array(issues_json_response)
    end

    context 'when work_item_epics and namespace_level_work_items feature flags are disabled' do
      before do
        stub_feature_flags(work_item_epics: false, namespace_level_work_items: false)
      end

      it 'returns response without group level work items', :aggregate_failures do
        issue_json_response = {
          'iid' => project_issue.iid,
          'title' => project_issue.title,
          'reference' => project_issue.to_reference(group)
        }

        get :issues, params: { group_id: group }

        expect(response).to have_gitlab_http_status(:ok)
        expect(json_response).to be_an(Array)
        expect(json_response.count).to eq(1)
        expect(json_response.first).to include(issue_json_response)
      end
    end
  end
end
