# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'User deletes feature flag', :js, feature_category: :feature_flags do
  include FeatureFlagHelpers

  let(:user) { create(:user) }
  let(:project) { create(:project, namespace: user.namespace) }

  let!(:feature_flag) do
    create_flag(project, 'ci_live_trace', false, description: 'For live trace feature')
  end

  before do
    project.add_developer(user)
    sign_in(user)

    visit(project_feature_flags_path(project))

    click_button('Delete')
    click_button('Delete feature flag')
    expect(page).to have_current_path(project_feature_flags_path(project))
  end

  it 'records audit event' do
    visit(project_audit_events_path(project))

    expect(page).to have_text("Deleted feature flag ci_live_trace.")
  end
end
