# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Projects > Settings > User changes default branch', feature_category: :groups_and_projects do
  let_it_be(:user) { create(:user) }
  let_it_be(:project) { create(:project, :repository, namespace: user.namespace) }
  let_it_be(:protected_branch) { create(:protected_branch, project: project, name: project.default_branch) }
  let(:default_branch_settings) { find('#default-branch-settings') }
  let(:default_branch_button) do
    within_testid('default-branch-dropdown') do
      find('button')
    end
  end

  let(:visit_repository_page) { visit project_settings_repository_path(project) }

  before do
    sign_in(user)
  end

  context 'with branch not protected by security policy' do
    it 'does not show popover if the default branch can be changed', :aggregate_failures, :js do
      visit_repository_page

      expect(default_branch_settings).not_to have_selector('[data-toggle="popover"]')
      expect(default_branch_button).not_to be_disabled
    end
  end

  context 'with branch protected by security policy' do
    include_context 'with scan result policy blocking protected branches' do
      let(:branch_name) { project.default_branch }
      let(:policy_configuration) do
        create(:security_orchestration_policy_configuration, project: project)
      end

      it 'disables the button and shows the popover if the default branch cannot be changed',
        :aggregate_failures,
        :js do
        visit_repository_page

        expect(default_branch_settings).to have_selector('[data-toggle="popover"]')
        expect(default_branch_button).to be_disabled
      end
    end
  end
end
