# frozen_string_literal: true

require 'spec_helper'

RSpec.describe ::Search, feature_category: :global_search do
  describe '.hash_namespace_id' do
    it 'returns modulo of string hash value' do
      namespace_id = instance_double(Integer)
      hash_value = 123
      maximum = 100

      expect(namespace_id).to receive_message_chain(:to_s, :hash).and_return hash_value
      expect(described_class.hash_namespace_id(namespace_id, maximum: maximum)).to eq(hash_value % maximum)
    end

    context 'when namespace id is nil' do
      it 'returns nil' do
        expect(described_class.hash_namespace_id(nil)).to be_nil
      end
    end
  end

  describe '.default_concurrency_limit' do
    it 'returns the default concurrency limit' do
      expect(described_class.default_concurrency_limit).to eq(described_class::DEFAULT_CONCURRENCY_LIMIT)
    end

    context 'when feature flag is disabled' do
      before do
        stub_feature_flags(search_sidekiq_default_concurrency_limit: false)
      end

      it 'returns nil' do
        expect(described_class.default_concurrency_limit).to be_nil
      end
    end
  end
end
