# frozen_string_literal: true

require 'spec_helper'
require_relative '../../../../lib/tasks/gitlab/custom_roles/compile_docs_task'

RSpec.describe Tasks::Gitlab::CustomRoles::CompileDocsTask, feature_category: :permissions do
  let(:docs_dir) { Rails.root.join("tmp/tests/doc/administration/custom_roles") }
  let(:docs_path) { Rails.root.join(docs_dir, 'abilities.md') }
  let(:template_erb_path) { Rails.root.join("tooling/custom_roles/docs/templates/custom_abilities.md.erb") }

  subject(:compile_docs_task) { described_class.new(docs_dir, docs_path, template_erb_path) }

  describe '#run' do
    it 'outputs message after compiling the documentation' do
      expect { compile_docs_task.run }.to output("Documentation compiled.\n").to_stdout
    end

    it 'creates abilities.md', :aggregate_failures do
      FileUtils.rm_f(docs_path)

      expect { File.read(docs_path) }.to raise_error(Errno::ENOENT)

      compile_docs_task.run

      expect(File.read(docs_path).size).not_to eq(0)
      expect(File.read(docs_path)).to match(/This documentation is auto generated by a Rake task/)
    end
  end
end
