# frozen_string_literal: true

module Resolvers
  module Security
    class VulnerabilityManagementPolicyResolver < BaseResolver
      include ResolvesOrchestrationPolicy

      type Types::Security::VulnerabilityManagementPolicyType, null: true

      argument :relationship, ::Types::SecurityOrchestration::SecurityPolicyRelationTypeEnum,
        description: 'Filter policies by the given policy relationship.',
        required: false,
        default_value: :direct

      argument :include_unscoped, GraphQL::Types::Boolean,
        description: 'Filter policies that are scoped to the project.',
        required: false,
        default_value: true

      def resolve(**args)
        policies = ::Security::VulnerabilityManagementPoliciesFinder.new(context[:current_user], object, args).execute
        construct_vulnerability_management_policies(policies)
      end
    end
  end
end
