# frozen_string_literal: true

module Resolvers
  module VulnerabilityFilterable
    extend ActiveSupport::Concern
    include ::Security::GroupIdentifierSearch

    private

    def validate_filters(filters)
      validate_owasp_top_ten(filters) if filters[:owasp_top_10].present?
      search_by_identifier_allowed!(vulnerable: object) if filters[:identifier_name].present?
    end

    def validate_owasp_top_ten(filters)
      owasp_top_ten = filters[:owasp_top_10]

      includes_filter_none = owasp_top_ten.include?(::Security::VulnerabilityReadsFinder::FILTER_NONE)

      return if owasp_top_ten.size <= 1

      return unless includes_filter_none

      raise ::Gitlab::Graphql::Errors::ArgumentError,
        'Incompatible argument: owasp_top_ten. "NONE" wildcard cannot be combined with other OWASP top 10 values.'
    end
  end
end
