# frozen_string_literal: true

module Types
  module VulnerabilityLocation
    # Vulnerability locations have their authorization enforced by VulnerabilityType
    # rubocop: disable Graphql/AuthorizeTypes
    class ClusterImageScanningType < BaseObject
      graphql_name 'VulnerabilityLocationClusterImageScanning'
      description 'Represents the location of a vulnerability found by a cluster image scan'

      field :dependency, ::Types::VulnerableDependencyType,
        null: true, description: 'Dependency containing the vulnerability.'

      field :image, GraphQL::Types::String,
        null: true, description: 'Name of the vulnerable container image.'

      field :operating_system, GraphQL::Types::String,
        null: true, description: 'Operating system that runs on the vulnerable container image.'

      field :kubernetes_resource,
        ::Types::VulnerableKubernetesResourceType,
        null: true,
        description: 'Kubernetes resource which uses the vulnerable container image.'
    end
  end
end
