# frozen_string_literal: true

module EE
  module Enums
    module Vulnerability
      extend ActiveSupport::Concern

      REPORT_TYPES = {
        dependency_scanning: 1,
        container_scanning: 2,
        dast: 3,
        coverage_fuzzing: 5,
        api_fuzzing: 6,
        cluster_image_scanning: 7,
        container_scanning_for_registry: 8,
        generic: 99
      }.freeze

      REPORT_TYPE_FEATURE_CATEGORIES = {
        api_fuzzing: 'dynamic_application_security_testing',
        dast: 'dynamic_application_security_testing',
        dependency_scanning: 'software_composition_analysis',
        cluster_image_scanning: 'container_scanning',
        container_scanning: 'container_scanning',
        container_scanning_for_registry: 'container_scanning',
        coverage_fuzzing: 'fuzz_testing'
      }.freeze

      class_methods do
        extend ::Gitlab::Utils::Override

        override :report_types
        def report_types
          @report_types ||= super.merge(REPORT_TYPES).sort_by(&:last).to_h.with_indifferent_access.freeze
        end

        override :report_type_feature_categories
        def report_type_feature_categories
          super.merge(REPORT_TYPE_FEATURE_CATEGORIES).to_h.freeze
        end

        def report_type_feature_category(report_type)
          report_type_feature_categories.fetch(report_type.to_sym, 'unknown')
        end
      end
    end
  end
end
