# frozen_string_literal: true

module Security
  class VulnerabilityReportDataEntity < Grape::Entity
    include ::API::Helpers::RelatedResourcesHelpers
    include ::CommitsHelper

    expose :id, as: :pipeline_id
    expose :iid, as: :pipeline_iid
    expose :source_ref, as: :source_branch

    expose :empty_state_svg_path do |_|
      ActionController::Base.helpers.image_path('illustrations/user-not-logged-in.svg')
    end

    expose :pipeline_jobs_path do |pipeline, options|
      expose_path(
        api_v4_projects_pipelines_jobs_path(id: options[:project].id, pipeline_id: pipeline.id)
      )
    end

    expose :vulnerability_exports_endpoint do |pipeline, options|
      expose_path(
        api_v4_security_projects_vulnerability_exports_path(
          id: options[:project].id
        )
      )
    end

    expose :project_full_path do |_, options|
      options[:project].path_with_namespace
    end

    expose :can_admin_vulnerability do |_, options|
      (options[:user].present? && options[:user].can?(:admin_vulnerability, options[:project])).to_s
    end

    expose :can_view_false_positive do |_, options|
      options[:project].licensed_feature_available?(:sast_fp_reduction).to_s
    end

    expose :has_jira_vulnerabilities_integration_enabled do |_, options|
      options[:project].configured_to_create_issues_from_vulnerabilities?.to_s
    end

    # This is named as has_vulnerabilities because we're reusing the component from
    # the vulnerability report on the pipeline security tab, though it is representing
    # whether any security_findings present in pipeline or not
    expose :has_vulnerabilities do |pipeline, options|
      pipeline.security_findings.exists?.to_s
    end

    expose :no_vulnerabilities_svg_path do |_|
      ActionController::Base.helpers.image_path('illustrations/empty-state/empty-search-md.svg')
    end

    def project_commit_path(...)
      Rails.application.routes.url_helpers.project_commit_path(...)
    end
  end
end
