# frozen_string_literal: true

module Security
  module ScanResultPolicies
    module VulnerabilityStatesHelper
      private

      # If vulnerability_states_for_branch is empty, it means that the
      # rule has newly_detected states for MR with non-default target branch.
      # We don't support newly_detected states for non-default target branch because
      # vulnerabilities are not persisted for non-default branch.
      def include_newly_detected?(approval_rule)
        states = approval_rule.vulnerability_states_for_branch
        states.present? && (states & ApprovalProjectRule::NEWLY_DETECTED_STATUSES).any?
      end

      def only_newly_detected?(approval_rule)
        states = approval_rule.vulnerability_states_for_branch
        states.present? && states.all? { |state| state.in?(ApprovalProjectRule::NEWLY_DETECTED_STATUSES) }
      end

      def states_without_newly_detected(vulnerability_states)
        vulnerability_states.reject { |state| ApprovalProjectRule::NEWLY_DETECTED_STATUSES.include?(state) }
      end

      def filter_newly_detected_rules(report_type, approval_rules)
        case report_type
        when :scan_finding
          approval_rules.select { |approval_rule| include_newly_detected?(approval_rule) }
        when :license_scanning
          approval_rules.select { |approval_rule| approval_rule.scan_result_policy_read&.newly_detected? }
        end
      end
    end
  end
end
