# frozen_string_literal: true

module Security
  module Ingestion
    class CreateVulnerabilityRepresentationInformation < BaseService
      include Gitlab::Ingestion::BulkInsertableTask

      self.model = Vulnerabilities::RepresentationInformation
      self.unique_by = :vulnerability_id

      def self.execute(...)
        new(...).execute
      end

      def initialize(pipeline, resolved_vulnerability_ids)
        @pipeline = pipeline
        @resolved_vulnerability_ids = resolved_vulnerability_ids
      end

      private

      attr_reader :pipeline, :resolved_vulnerability_ids

      def attributes
        resolved_vulnerability_ids.map do |id|
          {
            vulnerability_id: id,
            project_id: pipeline.project_id,
            resolved_in_commit_sha: pipeline.sha
          }
        end
      end
    end
  end
end
