# frozen_string_literal: true

module Vulnerabilities
  class UpdateTraversalIdsOfVulnerabilityStatisticService
    include Gitlab::ExclusiveLeaseHelpers

    LEASE_TTL = 5.minutes
    LEASE_TRY_AFTER = 3.seconds

    def self.execute(project_id)
      new(project_id).execute
    end

    def initialize(project_id)
      @project_id = project_id
    end

    def execute
      return unless project

      in_lock(lease_key, ttl: LEASE_TTL, sleep_sec: LEASE_TRY_AFTER) { update_vulnerability_statistic }
    end

    private

    attr_reader :project_id

    def lease_key
      "update_vulnerability_statistic_traversal_ids:projects:#{project_id}"
    end

    def project
      @project ||= Project.find_by_id(project_id)
    end

    def update_vulnerability_statistic
      project.vulnerability_statistic.update(traversal_ids: project.namespace.traversal_ids)
    end
  end
end
