# frozen_string_literal: true

module VulnerabilityScanners
  class ListService < BaseService
    def initialize(vulnerable)
      @vulnerable = vulnerable
    end

    def execute
      raise ArgumentError, 'Do not use this service on objects with ancestry.' unless @vulnerable.is_a?(::Project)

      @vulnerable
        .vulnerability_scanners
        .with_report_type
        .map do |scanner|
        {
          id: scanner.id,
          vendor: scanner.vendor,
          report_type: ::Enums::Vulnerability.report_types.key(scanner.report_type).upcase,
          name: scanner.name,
          external_id: scanner.external_id
        }
      end
    end
  end
end
