# frozen_string_literal: true

module Vulnerabilities
  class UpdateArchivedAttributeOfVulnerabilityReadsWorker
    include ApplicationWorker

    feature_category :vulnerability_management

    data_consistency :always
    worker_resource_boundary :memory
    idempotent!

    def perform(project_id)
      Vulnerabilities::UpdateArchivedOfVulnerabilityReadsService.execute(project_id)
    rescue Gitlab::ExclusiveLeaseHelpers::FailedToObtainLockError
      logger.info(
        class: self.class.name,
        message: "Couldn't obtain the lock. Rescheduling the job.",
        project_id: project_id)

      self.class.perform_in(5.minutes, project_id)
    end
  end
end
