# frozen_string_literal: true

module Vulnerabilities
  class UpdateTraversalIdsOfVulnerabilityStatisticWorker
    include ApplicationWorker

    LOCK_WAIT_TIME = 2.minutes

    feature_category :vulnerability_management

    data_consistency :sticky
    worker_resource_boundary :unknown
    idempotent!

    def perform(project_id)
      UpdateTraversalIdsOfVulnerabilityStatisticService.execute(project_id)
    rescue Gitlab::ExclusiveLeaseHelpers::FailedToObtainLockError
      logger.info(
        class: self.class.name,
        message: "Couldn't obtain the lock. Rescheduling the job.",
        project_id: project_id)

      self.class.perform_in(LOCK_WAIT_TIME, project_id)
    end
  end
end
