# frozen_string_literal: true

module VulnerabilityExports
  class ExportDeletionWorker
    include ApplicationWorker

    data_consistency :always

    sidekiq_options retry: 3

    feature_category :vulnerability_management

    idempotent!

    def perform(vulnerability_export_id)
      vulnerability_export = Vulnerabilities::Export.find_by_id(vulnerability_export_id)

      return unless vulnerability_export

      # We need to delete these records on application level to delete associated files.
      vulnerability_export.export_parts.each(&:destroy!)

      vulnerability_export.destroy!
    end
  end
end
