# frozen_string_literal: true

module EE
  module Gitlab
    module BackgroundMigration
      module FixCorruptedScannerIdsOfVulnerabilityReads
        extend ActiveSupport::Concern
        extend ::Gitlab::Utils::Override

        prepended do
          operation_name :fix_corrupted_scanner_ids_of_vulnerability_reads
          feature_category :vulnerability_management
        end

        override :perform
        def perform
          each_sub_batch { |sub_batch| connection.exec_update(update_sql(sub_batch)) }
        end

        private

        def update_sql(sub_batch)
          <<~SQL
            UPDATE vulnerability_reads
            SET scanner_id = vulnerability_occurrences.scanner_id
            FROM vulnerability_occurrences
            WHERE vulnerability_reads.vulnerability_id = vulnerability_occurrences.vulnerability_id
            AND vulnerability_reads.scanner_id != vulnerability_occurrences.scanner_id
            AND vulnerability_reads.id IN (#{sub_batch.select(:id).to_sql});
          SQL
        end
      end
    end
  end
end
