# frozen_string_literal: true

module Gitlab
  module DataBuilder
    module Vulnerability
      extend self

      def build(vulnerability)
        {
          object_kind: 'vulnerability',
          object_attributes: hook_attrs(vulnerability)
        }
      end

      def hook_attrs(vulnerability)
        {
          url: ::Gitlab::Routing.url_helpers.project_security_vulnerability_url(vulnerability.project, vulnerability),
          title: vulnerability.title,
          state: vulnerability.state,
          project_id: vulnerability.project_id,
          location: vulnerability.finding&.location,
          cvss: vulnerability.cvss,
          severity: vulnerability.severity,
          severity_overridden: vulnerability.severity_overridden,
          identifiers: identifiers_attrs(vulnerability.finding&.finding_identifiers),
          issues: issues_attrs(vulnerability.issue_links),
          report_type: vulnerability.report_type,
          confirmed_at: vulnerability.confirmed_at,
          confirmed_by_id: vulnerability.confirmed_by_id,
          dismissed_at: vulnerability.dismissed_at,
          dismissed_by_id: vulnerability.dismissed_by_id,
          resolved_on_default_branch: vulnerability.resolved_on_default_branch,
          created_at: vulnerability.created_at,
          updated_at: vulnerability.updated_at
        }
      end

      private

      def identifiers_attrs(finding_identifiers)
        return [] unless finding_identifiers

        finding_identifiers.map do |finding_identifiers|
          identifier = finding_identifiers.identifier

          {
            name: identifier.name,
            external_id: identifier.external_id,
            external_type: identifier.external_type,
            url: identifier.url
          }
        end
      end

      def issues_attrs(issue_links)
        return [] unless issue_links

        issue_links.map do |issue_link|
          issue = issue_link.issue
          vulnerability = issue_link.vulnerability

          {
            title: issue.title,
            url: ::Gitlab::Routing.url_helpers.project_issue_url(vulnerability.project, issue),
            created_at: issue.created_at,
            updated_at: issue.updated_at
          }
        end
      end
    end
  end
end
