# frozen_string_literal: true

module Gitlab
  module Llm
    module ResponseModifiers
      class ResolveVulnerability < ::Gitlab::Llm::BaseResponseModifier
        include Gitlab::Utils::StrongMemoize

        def response_body
          @response_body ||= ai_response&.dig(:merge_request_url).to_s
        end
        strong_memoize_attr :response_body

        def errors
          @errors ||= [ai_response&.dig('error', 'message'), empty_response_error].compact
        end

        private

        def empty_response_error
          case ai_response
          when {}, nil
            "The response from the AI provider was empty."
          when { 'false_positive' => true }
            "The response from the AI provider was empty because it has determined this vulnerability to be a false " \
              "positive. Use this feature with caution and always verify AI's response."
          when { 'merge_request_url' => nil }
            "No resolution merge request url was provided"
          end
        end
      end
    end
  end
end
