# frozen_string_literal: true

module Gitlab
  module VulnerabilityScanning
    # A PossiblyAffectedComponent represents a software component that is possibly affected
    # by a security advisory.
    class PossiblyAffectedComponent
      attr_reader :name, :version, :purl_type, :project, :pipeline, :source

      def initialize(name:, version:, purl_type:, project:, pipeline:, source:)
        @name = name
        @version = version
        @purl_type = purl_type
        @source = source
        @project = project
        @pipeline = pipeline
      end

      def self.from_sbom_occurrence(sbom_occurrence)
        new(
          purl_type: sbom_occurrence.purl_type,
          name: sbom_occurrence.name,
          version: sbom_occurrence.version,
          project: sbom_occurrence.project,
          pipeline: sbom_occurrence.pipeline,
          source: sbom_occurrence.source
        )
      end
    end
  end
end
