import { GlTableLite, GlButton } from '@gitlab/ui';
import { mountExtended } from 'helpers/vue_test_utils_helper';
import VulnerabilityArchivesTable from 'ee/security_configuration/components/vulnerability_archives_table.vue';

describe('Vulnerability Archive Table component', () => {
  let wrapper;

  const findTable = () => wrapper.findComponent(GlTableLite);
  const findTableHeaders = () => findTable().findAll('th');
  const findTableRowCells = (idx) => findTable().find('tbody').findAll('tr').at(idx).findAll('td');

  const createComponent = ({ propsData } = {}) => {
    wrapper = mountExtended(VulnerabilityArchivesTable, {
      propsData,
    });
  };

  beforeEach(() => {
    createComponent({
      propsData: {
        items: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11].map((month) => ({
          month,
          count: month * 5,
          download: true,
        })),
      },
    });
  });

  it('displays table headers properly', () => {
    const headers = findTableHeaders();
    expect(headers.at(0).text()).toBe('Month');
    expect(headers.at(1).text()).toBe('Vulnerabilities');
    expect(headers.at(2).text()).toBe('Download');
  });

  it.each`
    monthIndex | monthName
    ${0}       | ${'January'}
    ${1}       | ${'February'}
    ${2}       | ${'March'}
    ${3}       | ${'April'}
    ${4}       | ${'May'}
    ${5}       | ${'June'}
    ${6}       | ${'July'}
    ${7}       | ${'August'}
    ${8}       | ${'September'}
    ${9}       | ${'October'}
    ${10}      | ${'November'}
    ${11}      | ${'December'}
  `('displays table row properly for month: $monthName', ({ monthIndex, monthName }) => {
    const cells = findTableRowCells(monthIndex);
    expect(cells.at(0).text()).toBe(monthName);
    // See createWrapper method. We generate mock counts based on mountIndex
    expect(cells.at(1).text()).toBe(`${monthIndex * 5} vulnerabilities`);
    expect(cells.at(2).findComponent(GlButton).exists()).toBe(true);
  });
});
