# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Security::Configuration::ProjectSetContinuousVulnerabilityScanningService, feature_category: :software_composition_analysis do
  describe '#execute' do
    let_it_be(:security_setting) { create(:project_security_setting, continuous_vulnerability_scans_enabled: false) }
    let_it_be(:project) { security_setting.project }

    it 'returns attribute value' do
      expect(described_class.execute(project: project, enable: true)).to eq(true)
      expect(described_class.execute(project: project, enable: false)).to eq(false)
    end

    it 'changes the attribute' do
      expect { described_class.execute(project: project, enable: true) }
        .to change { security_setting.reload.continuous_vulnerability_scans_enabled }
        .from(false).to(true)
      expect { described_class.execute(project: project, enable: true) }
        .not_to change { security_setting.reload.continuous_vulnerability_scans_enabled }
      expect { described_class.execute(project: project, enable: false) }
        .to change { security_setting.reload.continuous_vulnerability_scans_enabled }
        .from(true).to(false)
      expect { described_class.execute(project: project, enable: false) }
        .not_to change { security_setting.reload.continuous_vulnerability_scans_enabled }
    end
  end
end
