# frozen_string_literal: true

require 'spec_helper'

RSpec.describe VulnerabilityScanners::ListService, feature_category: :vulnerability_management do
  let_it_be(:group) { create(:group) }
  let_it_be(:project) { create(:project, group: group) }
  let_it_be(:vulnerability_scanner) { create(:vulnerabilities_scanner, project: project, id: 123, external_id: "some_external_id") }
  let_it_be(:vulnerability_finding) { create(:vulnerabilities_finding, project: project, scanner: vulnerability_scanner) }

  let(:service) { described_class.new(vulnerable) }

  subject(:scanner_list) { service.execute }

  context 'when looking for scanners for group' do
    let(:vulnerable) { group }

    it { expect { scanner_list }.to raise_error(ArgumentError) }
  end

  context 'when looking for scanners for project' do
    let(:vulnerable) { project }

    it { is_expected.to match_array([{ id: 123, vendor: "Security Vendor", report_type: "SAST", name: "Find Security Bugs", external_id: "some_external_id" }]) }
  end
end
