# frozen_string_literal: true

RSpec.shared_examples 'vulnerability filterable' do |filter_key|
  describe '#validate_filters' do
    context 'for owasp_top_10' do
      context 'when filters are valid' do
        where(:filter_value) { %w[none A1_2017] }

        with_them do
          let(filter_key) { { owasp_top_ten: [filter_value] } }

          it 'does not raise any error' do
            is_expected.not_to be_instance_of(::Gitlab::Graphql::Errors::ArgumentError)
          end
        end
      end

      context 'when owasp_top_ten includes "none" and other values' do
        let(filter_key) { { owasp_top_ten: %w[none A1_2017] } }

        it 'raises an ArgumentError' do
          error_msg = 'Incompatible argument: owasp_top_ten. ' \
            '"NONE" wildcard cannot be combined with other OWASP top 10 values.'

          expect_graphql_error_to_be_created(Gitlab::Graphql::Errors::ArgumentError, s_(error_msg)) do
            subject
          end
        end
      end
    end
  end
end
