# frozen_string_literal: true

require 'spec_helper'

RSpec.shared_examples 'vulnerability and finding shared examples' do
  describe 'scopes' do
    let(:result_set_transformer) { transformer_method || :itself }
    let(:archive_associated_objects) { archived_project.vulnerabilities.map(&result_set_transformer) }

    let_it_be(:vulnerability) { create(:vulnerability, :with_finding, project: project) }
    let_it_be(:archived_project) do
      create(:project, :archived).tap { |p| create(:vulnerability, :with_finding, project: p) }
    end

    describe '.for_projects' do
      subject { described_class.for_projects(*params) }

      let(:params) { [[project.id, archived_project.id]] }
      let(:all_vulns_for_params) do
        (project.vulnerabilities + archived_project.vulnerabilities).map(&result_set_transformer)
      end

      before do
        # vulnerability associated on a project that will be filtered out
        create(:vulnerability, :with_finding, project: create(:project))
      end

      it 'returns objects related to the given project IDs' do
        is_expected.to contain_exactly(*all_vulns_for_params)
      end
    end
  end
end
